@@ -16,7 +16,7 @@ def return_pastfile(directory):
         if os.path.isfile(current_file):
 
             if current_file.endswith('.ini'):
-                if current_file in dev_files:
+              if current_file.endswith('dev.ini') or current_file.endswith('development.ini'):
                     return current_file
         else:
             if current_file not in exclude_directories:
@@ -45,9 +45,9 @@ class MultiPserve(object):
           Popen(['pserve', self.projects[dir_app], '--reload', log_file, pid_file],
                   stdout=PIPE, stderr=STDOUT)
         except Exception as e:
-          print e
+            print e
         else:
-          print 'init server {0}'.format(dir_app)
+            print 'init server {0}'.format(dir_app)
     
     def kill_servers(self, apps):
         '''the name says '''
